import 'package:dropbox_client/dropbox_client.dart' as dbx;
import 'package:dropbox_integration/Classes/Utils/API.dart';

import 'package:dropbox_integration/Classes/ALL.dart';


class FilesActions {

  final String userToken;
  FilesActions(this.userToken);

  get json => null;


  ///Upload a file to your Dropbox storage
  ///
  ///`localPath` is the path of the local file (the file on the device).
  ///`dropboxPath` is the path to the folder where the file will be placed
  ///
  ///__Required Dropbox Scope: files.content.write__
  ///
  /// * `dropboxPath` should start with "/" (that's root folder)
  Future<void> uploadFile(String localPath, String dropboxPath) async 
    => await dbx.Dropbox.upload(localPath, dropboxPath);



  ///Download a file from Dropbox storage to local storage
  ///
  ///`localPath` is the path where you want to download the file on the device (needs `WRITE_EXTERNAL_STORAGE` permission, [check this to do it](https://stackoverflow.com/a/50571167/10148111)).
  ///`dropboxPath` is the dropobox path from which the file will be downloaded (it must also contain the file extension)
  ///
  /// __Required Dropbox Scope: files.content.read__
  Future<void> downloadFile(String dropboxPath, String localPath) async 
    => await dbx.Dropbox.download(dropboxPath, localPath);


  ///Delete a file from Dropbox storage
  ///
  ///`filePath` must be the Dropbox file path that you want to delete
  ///Return the response (json) from the online api, print to console this response for more information about possible errors or set `printDebug` to true
  ///
  ///__Required Dropbox Scope: files.content.write__
  Future<String> deleteFile(String filePath, {bool printDebug = false}) async => await API.apiOnlineRequest(
    'https://api.dropboxapi.com/2/files/delete_v2', 
    {'path' : filePath},
    userToken,
    printDebug,
  );



  ///Copy a file or folder to a different location in the user's Dropbox.
  ///If the source path is a folder all its contents will be copied.
  ///
  ///__Required Dropbox Scope: files.content.write__
  ///
  /// * `fromPath` Path in the user's Dropbox to be copied or moved.
  /// * `toPath` Path in the user's Dropbox that is the destination. 
  /// * `autorename` If there's a conflict, have the Dropbox server try to autorename the file to avoid the conflict. The default for this field is False.
  /// * `allowOwnershipTransfer` Allow moves by owner even if it would result in an ownership transfer for the content being moved. This does not apply to copies. The default for this field is False. 
  Future<String> copyFile(String fromPath, String toPath, {bool printDebug = false, bool autorename = false, bool allowOwnershipTransfer = false}) async => await API.apiOnlineRequest(
    'https://api.dropboxapi.com/2/files/copy_v2', 
    {
      "from_path": fromPath,
      "to_path": toPath,
      "autorename": autorename,
      "allow_ownership_transfer": allowOwnershipTransfer
    }, 
    userToken, 
    printDebug,
  );


  ///Return a `List<DropboxFileTypes>` that contains user's files and directory
  Future<List<DropboxFileTypes>> getFilesList(String dropboxPath) async {
    List<DropboxFileTypes> _dbxFilesList = [];

    var list = await dbx.Dropbox.listFolder(dropboxPath);

    for (var rawFile in list) {
      if(rawFile.keys.length == 3){
        _dbxFilesList.add(DropboxDirectory.fromMap(rawFile));
      } else {
        _dbxFilesList.add(DropboxFile.fromMap(rawFile));
      }
    }

    return _dbxFilesList;
  }





}